pub struct GpioConfigureInterruptRequest {
pub config: InterruptConfiguration,
}Fields
config: InterruptConfigurationTrait Implementations
Sourceimpl Clone for GpioConfigureInterruptRequest
impl Clone for GpioConfigureInterruptRequest
Sourcefn clone(&self) -> GpioConfigureInterruptRequest
fn clone(&self) -> GpioConfigureInterruptRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, ___E> Encode<GpioConfigureInterruptRequest<'static>, ___E> for &'a GpioConfigureInterruptRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<GpioConfigureInterruptRequest<'static>, ___E> for &'a GpioConfigureInterruptRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GpioConfigureInterruptRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GpioConfigureInterruptRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GpioConfigureInterruptRequest<'static>, ___E> for GpioConfigureInterruptRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<GpioConfigureInterruptRequest<'static>, ___E> for GpioConfigureInterruptRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GpioConfigureInterruptRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GpioConfigureInterruptRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, GpioConfigureInterruptRequest<'static>>, ___E> for &'a GpioConfigureInterruptRequestwhere
___E: Encoder + ?Sized,
&'a GpioConfigureInterruptRequest: Encode<GpioConfigureInterruptRequest<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, GpioConfigureInterruptRequest<'static>>, ___E> for &'a GpioConfigureInterruptRequestwhere
___E: Encoder + ?Sized,
&'a GpioConfigureInterruptRequest: Encode<GpioConfigureInterruptRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GpioConfigureInterruptRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GpioConfigureInterruptRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, GpioConfigureInterruptRequest<'static>>, ___E> for GpioConfigureInterruptRequestwhere
___E: Encoder + ?Sized,
GpioConfigureInterruptRequest: Encode<GpioConfigureInterruptRequest<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, GpioConfigureInterruptRequest<'static>>, ___E> for GpioConfigureInterruptRequestwhere
___E: Encoder + ?Sized,
GpioConfigureInterruptRequest: Encode<GpioConfigureInterruptRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GpioConfigureInterruptRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GpioConfigureInterruptRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<GpioConfigureInterruptRequest<'de>> for GpioConfigureInterruptRequest
impl<'de> FromWire<GpioConfigureInterruptRequest<'de>> for GpioConfigureInterruptRequest
Sourcefn from_wire(wire: GpioConfigureInterruptRequest<'de>) -> Self
fn from_wire(wire: GpioConfigureInterruptRequest<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<GpioConfigureInterruptRequest<'de>> for GpioConfigureInterruptRequest
impl<'de> FromWireRef<GpioConfigureInterruptRequest<'de>> for GpioConfigureInterruptRequest
Sourcefn from_wire_ref(wire: &GpioConfigureInterruptRequest<'de>) -> Self
fn from_wire_ref(wire: &GpioConfigureInterruptRequest<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for GpioConfigureInterruptRequest
impl Hash for GpioConfigureInterruptRequest
Sourceimpl Ord for GpioConfigureInterruptRequest
impl Ord for GpioConfigureInterruptRequest
Sourcefn cmp(&self, other: &GpioConfigureInterruptRequest) -> Ordering
fn cmp(&self, other: &GpioConfigureInterruptRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for GpioConfigureInterruptRequest
impl PartialEq for GpioConfigureInterruptRequest
Sourcefn eq(&self, other: &GpioConfigureInterruptRequest) -> bool
fn eq(&self, other: &GpioConfigureInterruptRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for GpioConfigureInterruptRequest
impl PartialOrd for GpioConfigureInterruptRequest
impl Copy for GpioConfigureInterruptRequest
impl Eq for GpioConfigureInterruptRequest
impl StructuralPartialEq for GpioConfigureInterruptRequest