#[repr(C)]pub struct GpioReadResponse {
pub value: bool,
}Expand description
The wire type corresponding to GpioReadResponse.
Fields
value: boolTrait Implementations
Sourceimpl Clone for GpioReadResponse
impl Clone for GpioReadResponse
Sourcefn clone(&self) -> GpioReadResponse
fn clone(&self) -> GpioReadResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for GpioReadResponse
impl Constrained for GpioReadResponse
Sourceimpl Debug for GpioReadResponse
impl Debug for GpioReadResponse
Sourceimpl<___D> Decode<___D> for GpioReadResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for GpioReadResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<GpioReadResponse, ___E> for &'a GpioReadResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<GpioReadResponse, ___E> for &'a GpioReadResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GpioReadResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GpioReadResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GpioReadResponse, ___E> for GpioReadResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<GpioReadResponse, ___E> for GpioReadResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, GpioReadResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, GpioReadResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GpioReadResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GpioReadResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<GpioReadResponse, ___E> for GpioReadResponse<T0>
impl<___E, T0> Encode<GpioReadResponse, ___E> for GpioReadResponse<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GpioReadResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GpioReadResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<GpioReadResponse> for GpioReadResponse
impl FromWire<GpioReadResponse> for GpioReadResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GpioReadResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<GpioReadResponse, Self>
Sourcefn from_wire(wire: GpioReadResponse) -> Self
fn from_wire(wire: GpioReadResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<GpioReadResponse> for GpioReadResponse
impl FromWireRef<GpioReadResponse> for GpioReadResponse
Sourcefn from_wire_ref(wire: &GpioReadResponse) -> Self
fn from_wire_ref(wire: &GpioReadResponse) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for GpioReadResponse
impl IntoNatural for GpioReadResponse
Sourcetype Natural = GpioReadResponse
type Natural = GpioReadResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for GpioReadResponse
impl Wire for GpioReadResponse
Sourcetype Narrowed<'de> = GpioReadResponse
type Narrowed<'de> = GpioReadResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.